@@ -96,9 +96,9 @@ class Sensor:
             return convert_time(self.raw, self.sensorclass)
         if self.id == "boiler_status":
             return {
-                "burner": self.raw % 8 == 8,
-                "dhw": self.raw % 4 == 4,
-                "ch": self.raw % 2 == 2,
+                "burner": self.raw & 8 == 8,
+                "dhw": self.raw & 4 == 4,
+                "ch": self.raw & 2 == 2,
             }
         if self.id == "download_url":
             return self.raw.split("/")[-1]
@@ -157,20 +157,17 @@ class Control(Sensor):
             return self.raw % 150
         return self.raw
 
-    async def set_state(self, t):
+    async def set_state(self, target):
         """Set the Control to a new target state."""
-        s = None
-        if isinstance(t, str):
-            t = t.lower()
-            s = self.state.lower()
-
-        if t in [self.state, s]:
-            return True
-        self._target = t
+        target_int = None
         if self._states is not None:
-            t = {v.lower(): k for k, v in self._states.items()}.get(t)
+            target = {v.lower(): v for v in self._states.values()}.get(target.lower())
+            target_int = {v: k for k, v in self._states.items()}.get(target)
+        if target == self.state:
+            return True
+        self._target = target
         self._last_call = datetime.utcnow()
-        return await self._setter(**{self.id: t})
+        return await self._setter(**{self.id: target_int or target})
 
 
 class Climate:
